@@ -1,20 +1,18 @@
 '''浏览器截图'''
-from .driver import get_driver
 import platform
 from loguru import logger
 from .config import ayaka_root_config
+from .driver import get_driver
 
+driver = get_driver()
 running_on_windows = platform.system() == "Windows"
-fastapi_reload = getattr(get_driver().config, "fastapi_reload", True)
+fastapi_reload = getattr(driver.config, "fastapi_reload", True)
 
 if ayaka_root_config.use_playwright:
-    import datetime
     from playwright.async_api import async_playwright, Browser, Page, Playwright
     from contextlib import asynccontextmanager
     from typing import AsyncIterator
-    from .driver import get_driver
 
-    driver = get_driver()
     _browser: Browser = None
     _playwright: Playwright = None
 
@@ -39,9 +37,6 @@ if ayaka_root_config.use_playwright:
 
     @driver.on_startup
     async def startup():
-        with open("test.log", "a+", encoding="utf8") as f:
-            d = datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")
-            f.write(f"[{d}] 记录时间  playwright init\n")
         print('''
 
     playwright init
@@ -58,9 +53,6 @@ if ayaka_root_config.use_playwright:
     @driver.on_shutdown
     async def shutdown():
         # 查bug 怀疑卡死原因是没有正确退出
-        with open("test.log", "a+", encoding="utf8") as f:
-            d = datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")
-            f.write(f"[{d}] 记录时间  playwright close\n")
         print('''
 
     playwright close
